'filesysobjects.FileSysObjects' - Module
****************************************

.. automodule:: filesysobjects.FileSysObjects

Functions
---------

addPathToSearchPath
^^^^^^^^^^^^^^^^^^^
	.. autofunction:: addPathToSearchPath

clearPath
^^^^^^^^^
	.. autofunction:: clearPath

delPathFromSearchPath
^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: delPathFromSearchPath

escapeFilePath
^^^^^^^^^^^^^^
	.. autofunction:: escapeFilePath

findRelPathInSearchPath
^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: findRelPathInSearchPath

findRelPathInSearchPathIter
^^^^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: findRelPathInSearchPathIter

findRelPathInUpperTree
^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: findRelPathInUpperTree

getAppPrefixLocalPath
^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getAppPrefixLocalPath

getTopFromPathString
^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getTopFromPathString

getTopFromPathStringIter
^^^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: getTopFromPathStringIter

normpathX
^^^^^^^^^
	.. autofunction:: normpathX

setUpperTreeSearchPath
^^^^^^^^^^^^^^^^^^^^^^
	.. autofunction:: setUpperTreeSearchPath

splitAppPrefix
^^^^^^^^^^^^^^
	.. autofunction:: splitAppPrefix

unescapeFilePath
^^^^^^^^^^^^^^^^
	.. autofunction:: unescapeFilePath

Exceptions
----------

FileSysObjectsException
^^^^^^^^^^^^^^^^^^^^^^^
	.. autoclass:: FileSysObjectsException

